@@ -79,9 +79,7 @@ $(document).ready(function() {
 });
 
 /**
- * "innerHTML = html" is pretty slow in FF.  Happily a lot of our innerHTML
- * changes are triggered by periodic refreshes on torrents whose state hasn't
- * changed since the last update, so even this simple test helps a lot.
+ * Checks to see if the content actually changed before poking the DOM.
  */
 function setInnerHTML(e, html)
 {
@@ -98,6 +96,22 @@ function setInnerHTML(e, html)
 	}
 };
 
+function sanitizeText(text)
+{
+	return text.replace(/</g, "&lt;").replace(/>/g, "&gt;");
+};
+
+/**
+ * Many of our text changes are triggered by periodic refreshes
+ * on torrents whose state hasn't changed since the last update,
+ * so see if the text actually changed before poking the DOM.
+ */
+function setTextContent(e, text)
+{
+	if (e && (e.textContent != text))
+		e.textContent = text;
+};
+
 /*
  *   Given a numerator and denominator, return a ratio string
  */
@@ -182,9 +196,8 @@ Prefs.setValue = function(key, val)
 	if (!(key in Prefs._Defaults))
 		console.warn("unrecognized preference key '%s'", key);
 
-	var days = 30;
 	var date = new Date();
-	date.setTime(date.getTime()+(days*24*60*60*1000));
+	date.setFullYear (date.getFullYear() + 1);
 	document.cookie = key+"="+val+"; expires="+date.toGMTString()+"; path=/";
 };
 
